Core protocol types and layout constants for crossbar pub/sub.
Pure atomics, raw pointer math, and lock-free data structures (Treiber stack, seqlock, ring).
Core protocol types and layout constants for crossbar pub/sub.
Pure atomics, raw pointer math, and lock-free data structures (Treiber stack, seqlock, ring).